@@ -2,9 +2,8 @@
 ## Name:        HtmlEasy.pm
 ## Purpose:     Pod::HtmlEasy
 ## Author:      Graciliano M. P. 
-## Modified by: Geoffrey Leach
+## Modified by:
 ## Created:     2004-01-11
-## Updated:	2006-11-12
 ## RCS-ID:      
 ## Copyright:   (c) 2004 Graciliano M. P. 
 ## Licence:     This program is free software; you can redistribute it and/or
@@ -17,11 +16,10 @@ use 5.006 ;
 use Pod::HtmlEasy::Parser ;
 use Pod::HtmlEasy::TiehHandler ;
 
-use strict ;
-use warnings ;
+use strict qw(vars) ;
 
 use vars qw($VERSION @ISA) ;
-$VERSION = '0.08_02' ;
+$VERSION = '0.01' ;
 
 ########
 # VARS #
@@ -138,14 +136,6 @@ table.dlsip     {
 }
 ` ;
 
-###############
-# DEFAULT_CSS #
-###############
-
-sub default_css {
-  return $CSS_DEF ;
-}
-
 #######
 # NEW #
 #######
@@ -160,50 +150,27 @@ sub new {
 
   $this->{ON_B} = $args{on_B} || \&evt_on_B ;
   $this->{ON_C} = $args{on_C} || \&evt_on_C ;
-  $this->{ON_E} = $args{on_E} || \&evt_on_E ;
-  $this->{ON_F} = $args{on_F} || \&evt_on_F ;
   $this->{ON_I} = $args{on_I} || \&evt_on_I ;
   $this->{ON_L} = $args{on_L} || \&evt_on_L ;
-  $this->{ON_S} = $args{on_S} || \&evt_on_S ;
-  $this->{ON_X} = $args{on_X} || \&evt_on_X ; # [20078]
-  $this->{ON_Z} = $args{on_Z} || \&evt_on_Z ;
   
   $this->{ON_HEAD1} = $args{on_head1} || \&evt_on_head1 ;
   $this->{ON_HEAD2} = $args{on_head2} || \&evt_on_head2 ;
   $this->{ON_HEAD3} = $args{on_head3} || \&evt_on_head3 ;
-  $this->{ON_HEAD4} = $args{on_head4} || \&evt_on_head4 ;
   
-  $this->{ON_VERBATIM} = $args{on_verbatim} || \&evt_on_verbatim ;
-  $this->{ON_VERBATIM} = $args{on_verbatin} if defined $args{on_verbatin} ;
+  $this->{ON_VERBATIN} = $args{on_verbatin} || \&evt_on_verbatin ;
   $this->{ON_TEXTBLOCK} = $args{on_textblock} || \&evt_on_textblock ;
   
   $this->{ON_OVER} = $args{on_over} || \&evt_on_over ;
-  $this->{ON_ITEM} = $args{on_item} || \&evt_on_item ;
+  $this->{ON_ITEM} = $args{_on_item} || \&evt_on_item ;
   $this->{ON_BACK} = $args{on_back} || \&evt_on_back ;
-
-  $this->{ON_FOR}  = $args{on_for} || \&evt_on_for ;
-  $this->{ON_BEGIN} = $args{on_begin} || \&evt_on_begin ;
-  $this->{ON_END}   = $args{on_end}   || \&evt_on_end ;
   
   $this->{ON_INDEX_NODE_START} = $args{on_index_node_start} || \&evt_on_index_node_start ;
   $this->{ON_INDEX_NODE_END} = $args{on_index_node_end} || \&evt_on_index_node_end ;
 
   $this->{ON_INCLUDE} = $args{on_include} || \&evt_on_include ;
-  $this->{ON_URI} = $args{on_uri} || \&evt_on_uri ;
 
   $this->{ON_ERROR} = $args{on_error} || \&evt_on_error ;
   
-  foreach my $Key ( keys %args ) {
-    if ( $Key =~ /^on_(\w+)$/ ) {
-      my $cmd = uc($1);
-      $this->{"ON_$cmd"} = $args{$Key} if !$this->{"ON_$cmd"} ;
-    }
-    elsif ( $Key =~ /^(?:=(\w+)|(\w)<>)$/ ) {
-      my $cmd = uc( $1 || $2 );
-      $this->{$cmd} = $args{$Key} if !$this->{$cmd} ;
-    }
-  }
-  
   return $this ;
 }
 
@@ -213,25 +180,18 @@ sub new {
 
 sub pod2html {
   my $this = shift ;
+  
   my $file = shift ;
-  my $save = ($_[0] !~ /^(?:file|title|body|css|index|top|only_content|no_index|no_css|index_item)$/i) ? shift : undef ;
+  my $save = shift if $_[0] !~ /^(?:file|title|body|css|index|only_content|no_index|no_css)$/i ;
   my ( %args ) = @_ ;
 
   my $parser = Pod::HtmlEasy::Parser->new() ;
   $parser->errorsub( sub { &Pod::HtmlEasy::Parser::_errors($parser , @_) ;} ) ;
-  # Complains about multiple blank lines in the input
-  #$parser->parseopts(-warnings => 1);
   $parser->{POD_HTMLEASY} = $this ;
   
-  $parser->{INDEX_ITEM} = 1 if $args{index_item} ;
-  
-  $parser->{BASIC_ENTITIES} = 1 if $args{basic_entities} ;
-  $parser->{COMMON_ENTITIES} = 1 if $args{common_entities} ;
-  
   local(*PODIN , *PODOUT) ;
-  my $podin_tied;
   
-  my $output = ''; # [6062]
+  my $output ;
   tie(*PODOUT => 'Pod::HtmlEasy::TiehHandler' , \$output) ;
   
   $this->{OUTPUT} = \$output ;
@@ -239,12 +199,10 @@ sub pod2html {
   
   my $io ;
   if ( ref($file) eq 'GLOB' ) { $io = $file ;}
-  elsif ( ($file =~ /[\r\n]/s || $file eq '' ) && !-e $file ) {
+  elsif ( $file =~ /[\r\n]/s && !-e $file ) {
     tie(*PODIN => 'Pod::HtmlEasy::TiehHandler' , \$file) ;
     $io = \*PODIN ;
-    $podin_tied = 1; # [6062]
   }
-  elsif ( !-e $file ) { return ;}
   
   delete $this->{INDEX} ;
   
@@ -256,10 +214,8 @@ sub pod2html {
   
   close(PODOUT) ;
   untie (*PODOUT) ;
-  if ( defined $podin_tied ) { # [6062]
-      close(PODIN) ;
-      untie (*PODIN) ;
-  }
+  close(PODIN) ;
+  untie (*PODIN) ;
   
   $args{file} = $file if $file ;
   
@@ -268,21 +224,18 @@ sub pod2html {
   my $html ;
   
   if ( $args{only_content} ) {
-    $html = "<a name='_top'></a>$args{top}$args{index}<div class='pod'><div>$output</div></div>\n"; # [21646]
+    $html = "$args{index}<div class='pod'><div>$output<div></div>\n"
   }
   else {
     $html = $this->build_html("$output\n" , %args) ;
   }
   
-  if ( $save && $save !~ /[\r\n]/s ) {
+  if ( $save && $save !~ /\s/s ) {
     open (my $out,">$save") ;
     print $out $html ;
     close($out) ;
   }
   
-  $parser = undef ; ## undef due closure at errorsub() ;
-  $parser->{POD_HTMLEASY} = undef ;
-  
   return $html ;
 }
 
@@ -304,31 +257,34 @@ sub parse_include {
   return 1 ;
 }
 
-##############
-# WALK_INDEX #
-##############
+#############
+# WALK_TREE #
+#############
 
-sub walk_index {
-  my ( $this , $tree , $on_open , $on_close , $output ) = @_ ;
+sub walk_tree {
+  my ( $this , $tree , $on_open , $on_close , $on_value , $output ) = @_ ;
   
-  for(my $i = 0 ; $i < @$tree ; $i+=2) {
-    my $nk = ref( $$tree[$i+1] ) eq 'ARRAY' ? @{ $$tree[$i+1] } : undef ;
+  foreach my $Key ( keys %$tree ) {
+    my $nk = keys %{ $$tree{$Key} } if ref($$tree{$Key}) eq 'HASH' ;
     $nk = $nk >= 1 ? 1 : undef ;
     
-    my $a_name = $$tree[$i] ;
-    $a_name =~ s/<.*?>//gs ;
+    my $a_name = $Key ;
     $a_name =~ s/\W/-/gs ;
 
     if ( $on_open ) {
-      my $ret = &$on_open($this , $$tree[$i] , $a_name , $nk) ;
-      $$output .= $ret if $output  and defined $ret; # [6062]
+      my $ret = &$on_open($this , $Key , $a_name , $nk) ;
+      $$output .= $ret if $output ;
     }
     
-    if ( $nk ) { walk_index( $this , $$tree[$i+1] , $on_open , $on_close , $output ) ;}
-    
+    if ( ref($$tree{$Key}) eq 'HASH' ) { walk_tree( $this , $$tree{$Key} , $on_open , $on_close , $on_value , $output ) ;}
+    elsif ($on_value) {
+      my $ret = &$on_value($this , $Key , $a_name , $$tree{$Key}) ;
+      $$output .= $ret if $output ;
+    }
+
     if ( $on_close ) {
-      my $ret = &$on_close($this , $$tree[$i] , $a_name , $nk) ;
-      $$output .= $ret if $output and defined $ret ; # [6062]
+      my $ret = &$on_close($this , $Key , $a_name , $nk) ;
+      $$output .= $ret if $output ;
     }
   }
 }
@@ -340,8 +296,8 @@ sub walk_index {
 sub build_index {
   my $this = shift ;
   
-  my $index = ''; # [6062]
-  $this->walk_index( $this->{INDEX} , $this->{ON_INDEX_NODE_START} , $this->{ON_INDEX_NODE_END} , \$index ) ;
+  my $index ;
+  $this->walk_tree( $this->{INDEX} , $this->{ON_INDEX_NODE_START} , $this->{ON_INDEX_NODE_END} , undef , \$index ) ;
   
   $index = qq`<div class="toc">
 <ul>
@@ -394,7 +350,7 @@ sub build_html {
     $css = $buffer ;
   }
   
-  if ( $css !~ /[\r\n]/s ) {
+  if ( $css !~ /[\r\n]/s && -e $css ) {
     $css = qq`<link rel="stylesheet" href="$css" type="text/css">` ;
   }
   elsif ( $css =~ /\S/s ) { $css = qq`<style type="text/css">
@@ -404,21 +360,20 @@ $css
   }
   else { $css = '' ;}
   
-  my $gen = $args{no_generator} ? '' : qq`<meta name="GENERATOR" content="Pod::HtmlEasy/$VERSION Perl/$] [$^O]">\n` ;
+  my $gen = "Pod::HtmlEasy/$VERSION Perl/$] [$^O]" ;
 
-$args{top} = '' unless exists $args{top}; # [6062]
 my $html = qq`<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
 <html><head>
 <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-$gen<title>$title</title>
+<meta name="GENERATOR" content="$gen">
+<title>$title</title>
 $css
 </head>
-<body$body><a name='_top'></a>
-$args{top}
+<body$body><a name="_top"></a>
 $args{index}
 <div class='pod'><div>
 $content
-</div></body></html>
+<div></div></body></html>
 ` ;
 }
 
@@ -429,39 +384,19 @@ $content
 sub evt_on_head1 {
   my $this = shift ;
   my ( $txt , $a_name ) = @_ ;
-  return "<a name='$a_name'></a><h1>$txt</h1>\n\n" ;
+  return "<a name='$a_name'><h1>$txt</h1>\n\n" ;
 }
 
 sub evt_on_head2 {
   my $this = shift ;
   my ( $txt , $a_name ) = @_ ;
-  return "<a name='$a_name'></a><h2>$txt</h2>\n\n" ;
+  return "<a name='$a_name'><h2>$txt</h2>\n\n" ;
 }
 
 sub evt_on_head3 {
   my $this = shift ;
   my ( $txt , $a_name ) = @_ ;
-  return "<a name='$a_name'></a><h3>$txt</h3>\n\n" ;
-}
-
-sub evt_on_head4 {
-  my $this = shift ;
-  my ( $txt , $a_name ) = @_ ;
-  return "<a name='$a_name'></a><h4>$txt</h4>\n\n" ;
-}
-
-sub evt_on_begin {
-  my $this = shift ;
-  my ( $txt , $a_name ) = @_ ;
-  $this->{IN_BEGIN} = 1;
-  return '';
-}
-
-sub evt_on_end {
-  my $this = shift ;
-  my ( $txt , $a_name ) = @_ ;
-  delete $this->{IN_BEGIN};
-  return '';
+  return "<a name='$a_name'><h3>$txt</h3>\n\n" ;
 }
 
 sub evt_on_L {
@@ -469,8 +404,7 @@ sub evt_on_L {
   my ( $L , $text, $page , $section, $type ) = @_ ;
   
   if   ( $type eq 'pod' ) {
-    $section = defined $section ? "#$section" : ''; # [6062]
-    $page = '' unless defined $page; # [6062]
+    $section = "#$section" if $section ne '' ;
     return "<i><a href='http://search.cpan.org/perldoc?$page$section'>$text</a></i>" ;
   }
   elsif( $type eq 'man' ) { return "<i>$text</i>" ;}
@@ -492,59 +426,18 @@ sub evt_on_I {
 sub evt_on_C {
   my $this = shift ;
   my ( $txt ) = @_ ;
-  return "<font face='Courier New'>$txt</font>" ;
+  return "<pre>$txt</pre>" ;
 }
 
-sub evt_on_E {
+sub evt_on_verbatin {
   my $this = shift ;
   my ( $txt ) = @_ ;
-  
-  return '&lt;' if $txt =~ /^lt$/i ;
-  return '&gt;' if $txt =~ /^gt$/i ;
-  return '|' if $txt =~ /^verbar$/i ;
-  return '/' if $txt =~ /^sol$/i ;
-  
-  return "&#$txt;" if $txt =~ /^\d+$/ ;
-  
-  return "&$txt;" if defined $Pod::HtmlEasy::Parser::ENTITIES{$txt} ;
-  
-  return $txt ;
-}
-
-sub evt_on_F {
-  my $this = shift ;
-  my ( $txt ) = @_ ;
-  return "<b><i>$txt</i></b>" ;
-}
-
-sub evt_on_S {
-  my $this = shift ;
-  my ( $txt ) = @_ ;
-  $txt =~ s/\n/ /gs ;
-  return $txt ;
-}
-
-sub evt_on_X { return '' ; } # [20078]
-
-sub evt_on_Z { return '' ; }
-
-sub evt_on_verbatim {
-  my $this = shift ;
-  return if exists $this->{IN_BEGIN};
-  my ( $txt ) = @_ ;
-
-  # Multiple empty lines are parsed as verbatim text by Pod::Parser
-  # And will show up as empty <pre> blocks, which is mucho messy
-  $txt =~ s{(^[\r\n])*(^[\r\n])\z}{}mg;
-  return '' unless length $txt;
-
   return "<pre>$txt</pre>\n" ;
 }
 
 sub evt_on_textblock {
   my $this = shift ;
   my ( $txt ) = @_ ;
-  return if exists $this->{IN_BEGIN};
   return "<p>$txt</p>\n" ;
 }
 
@@ -556,9 +449,8 @@ sub evt_on_over {
 
 sub evt_on_item {
   my $this = shift ;
-  my ( $txt , $a_name ) = @_ ;
-  return "<li>" if $txt =~ /^(?:\*|\s*<[bi]\s*>\s*\*\s*<\/[bi]\s*>)$/si ;
-  return "<li><a name='$a_name'></a><b>$txt</b></li>\n" ;
+  my ( $txt ) = @_ ;
+  return "<li>$txt</li>\n" ;
 }
 
 sub evt_on_back {
@@ -566,8 +458,6 @@ sub evt_on_back {
   return "</ul>\n" ;
 }
 
-sub evt_on_for { return '' ;}
-
 sub evt_on_error {
   my $this = shift ;
   my ( $txt ) = @_ ;
@@ -580,15 +470,6 @@ sub evt_on_include {
   return $file ;
 }
 
-sub evt_on_uri {
-  my $this = shift ;
-  my ( $uri ) = @_ ;
-  my $target = ($uri !~ /^(?:mailto|telnet|ssh|irc):/i) ? " target='_blank'" : '' ; # [6062]
-  my $txt = $uri ;
-  $txt =~ s/^mailto://i ;
-  return "<a href='$uri'$target>$txt</a>" ;
-}
-
 sub evt_on_index_node_start {
   my $this = shift ;
   my ( $txt , $a_name , $has_childs ) = @_ ;
@@ -603,28 +484,23 @@ sub evt_on_index_node_end {
   my $this = shift ;
   my ( $txt , $a_name , $has_childs ) = @_ ;
   
-  my $ret = $has_childs ? "</ul>" : undef ;
+  my $ret = "</ul>" if $has_childs ;
   
   return $ret ;
 }
 
-##############
-# PM_VERSION #
-##############
+#########
+# UTILS #
+#########
 
 sub pm_version {
-  my $this = ref($_[0]) ? shift : undef ;
   my ( $file ) = @_ ;
-  
-  return if $file !~ /\.pm$/i ;
-  
   my ($ver,$buffer) ;
 
   open (my $fh,$file) ;
-  while( read($fh, $buffer , 1024*4 , length($buffer) ) ) {
+  while( read($fh, $buffer , 1024 , length($buffer) ) ) {
     my ($v) = ( $buffer =~ /\$VERSION\s*=\s*[^\s\d\.]*([\d\.]+)./s ) ;
     if ($v ne '') { $ver = $v ; last ;}
-    last if length($buffer) > 1024*100 ;
   }
   close ($fh) ;
   
@@ -636,126 +512,37 @@ sub pm_version {
 ##############
 
 sub pm_package {
-  my $this = ref($_[0]) ? shift : undef ;
   my ( $file ) = @_ ;
-  
-  return if $file !~ /\.pm$/i ;
-  
   my ($pack,$buffer) ;
 
   open (my $fh,$file) ;
-  while( read($fh, $buffer , 1024*4 , length($buffer) ) ) {
-    my ($p) = ( $buffer =~ /(?:^|\W)package\s+(\w+(?:::\w+)*)\W/s ) ;
+  while( read($fh, $buffer , 1024 , length($buffer) ) ) {
+    my ($p) = ( $buffer =~ /\Wpackage\s+\w+(?:::\w+)*\W/s ) ;
     if ($p ne '') { $pack = $p ; last ;}
-    last if length($buffer) > 1024*100 ;
   }
   close ($fh) ;
   
   return( $pack ) ;
 }
 
-###########
-# PM_NAME #
-###########
-
-sub pm_name {
-  my $this = ref($_[0]) ? shift : undef ;
-  my ( $file ) = @_ ;
-  
-  return if $file =~ /(?:^|[\\\/])perllocal\.pod$/i ;
-  
-  my $is_pod = ($file =~ /\.pod$/i) ? 1 : undef ;
-  
-  my ($name,$h1 , $buffer,$found_end) ;
-
-  open (my $fh,$file) ;
-  while( read($fh, $buffer , 1024*4 , length($buffer) ) ) {
-    my ($n) = ( $buffer =~ /(?:^|\r\n|\n)=head1\s+NAME[ \t]*(?:\r\n|\n)\s*([^\r\n]+)/s ) ;
-    if ($n ne '') { $name = $n ; last ;}
-    
-    ($h1) = ( $buffer =~ /(?:^|\r\n|\n)=head1[ \t]+([^\r\n]+)/s ) ;
-    
-    if ( !$is_pod ) {
-      if ( $buffer =~ /^(.*)(?:\r\n|\n)__END__(?:\r\n|\n)/s ) { $found_end = length($1) ;}
-    }
-    
-    last if (($is_pod && length($buffer) > 1024*10) || (!$is_pod && $found_end && (length($buffer)-$found_end) > 1024*10)  ) ;
-  }
-  close ($fh) ;
-  
-  $name ||= $h1 ; 
-  
-  $name =~ s/\s+$//gs ;
-  
-  return( $name ) ;
-}
-
-###########################
-# PM_PACKAGE_VERSION_NAME #
-###########################
-
-sub pm_package_version_name {
-  my $this = ref($_[0]) ? shift : undef ;
-  my ( $file ) = @_ ;
-  
-  return if $file =~ /(?:^|[\\\/])perllocal\.pod$/i ;
-  
-  my $is_pm = ($file =~ /\.pm$/i) ? 1 : undef ;
-  my $is_pod = ($file =~ /\.pod$/i) ? 1 : undef ;
-  
-  my ($pack,$ver,$name , $h1 , $buffer , $found_end , $read_n) ;
-  
-  $read_n = 3 ;
-
-  open (my $fh,$file) ;
-  while( read($fh, $buffer , 1024*(2**$read_n) , length($buffer) ) ) {
-    my ($p,$v,$n) ;
-    ($p) = ( $buffer =~ /(?:^|\W)package\s+(\w+(?:::\w+)*)\W/s ) if !$pack ;
-    if ($p ne '') { $pack = $p ;}
-    
-    ($v) = ( $buffer =~ /\$VERSION\s*=\s*[^\s\d\.]*([\d\.]+)./s ) if !$ver ;
-    if ($v ne '') { $ver = $v ;}
-
-    ($n) = ( $buffer =~ /(?:^|\r\n|\n)=head1[ \t*]NAME[ \t]*(?:\r\n|\n)\s*([^\r\n]+)/s ) if !$name ;
-    if ($n ne '') { $name = $n ;}
-    
-    ($h1) = ( $buffer =~ /(?:^|\r\n|\n)=head1[ \t]+([^\r\n]+)/s ) ;
-    
-    if ( !$is_pod ) {
-      if ( $buffer =~ /^(.*)(?:\r\n|\n)__END__(?:\r\n|\n)/s ) { $found_end = length($1) ;}
-    }
-    
-    if (( ($p && $v || !$is_pm) && $n) || ($is_pod && length($buffer) > 1024*10) || (!$is_pod && length($buffer) > 1024*900) || ($found_end && (length($buffer)-$found_end) > 1024*10) ) { last ;}
-    
-    ++$read_n ;
-  }
-  close ($fh) ;
-  
-  $name ||= $h1 ;
-  
-  $name =~ s/\s+$//gs ;
-  
-  return( $pack,$ver,$name ) ;
-}
-
 #######
 # END #
 #######
 
 1;
 
+
 __END__
 
 =head1 NAME
 
-Pod::HtmlEasy - Generate easy and personalized HTML from PODs,
-without extra modules and on "the flight".
+Pod::HtmlEasy - Generate HTML from POD easy, without extra modules and on the flight.
 
 =head1 DESCRIPTION
 
-The purpose of this module is to generate HTML data from POD in a easy and personalized mode.
+The purpose of this module is to generate HTML data from POD in a easy and personalizable mode.
 
-By default the HTML generated is similar to the CPAN site style for module documentation.
+By default the HTML generated is simillar to CPAN style for modules documentations.
 
 =head1 USAGE
 
@@ -764,7 +551,7 @@ Simple usage:
   my $podhtml = Pod::HtmlEasy->new() ;
 
   my $html = $podhtml->pod2html( 'test.pod' ) ;
-
+  
   print "$html\n" ;
 
 Complete usage:
@@ -773,111 +560,63 @@ Complete usage:
 
   ## Create the object and set my own events subs:
   ## ** Note that here are all the events, and examples of how to implement **
-  ## ** them, and actually this are the default events, so you don't need   **
+  ## ** them, and actually this are the default events, soo you don't need  **
   ## ** to set everything.                                                  **
 
-  my $podhtml = Pod::HtmlEasy->new (
+  my $podhtml = Pod::HtmlEasy->new(
+  on_head1     => sub {
+                    my ( $this , $txt , $a_name ) = @_ ;
+                    return "<a name='$a_name'><h1>$txt</h1>\n\n" ;
+                  } ,
+
+  on_head2     => sub {
+                    my ( $this , $txt , $a_name ) = @_ ;
+                    return "<a name='$a_name'><h2>$txt</h2>\n\n" ;
+                  } ,
+
+  on_head3     => sub {
+                    my ( $this , $txt , $a_name ) = @_ ;
+                    return "<a name='$a_name'><h3>$txt</h3>\n\n" ;
+                  } ,
+
+  on_L         => sub {
+                    my ( $this , $L , $text, $page , $section, $type ) = @_ ;
+                    if   ( $type eq 'pod' ) {
+                      $section = "#$section" if $section ne '' ;
+                      return "<i><a href='http://search.cpan.org/perldoc?$page$section'>$text</a></i>" ;
+                    }
+                    elsif( $type eq 'man' ) { return "<i>$text</i>" ;}
+                    elsif( $type eq 'url' ) { return "<a href='$page' target='_blank'>$text</a>" ;}
+                  } ,
 
   on_B         => sub {
                     my ( $this , $txt ) = @_ ;
                     return "<b>$txt</b>" ;
                   } ,
 
-  on_C         => sub {
-                    my ( $this , $txt ) = @_ ;
-                    return "<font face='Courier New'>$txt</font>" ;
-                  } ,
-
-  on_E         => sub {
-                    my ( $this , $txt ) = @_ ;
-                    return '<' if $txt =~ /^lt$/i ;
-                    return '>' if $txt =~ /^gt$/i ;
-                    return '|' if $txt =~ /^verbar$/i ;
-                    return '/' if $txt =~ /^sol$/i ;
-                    return chr($txt) if $txt =~ /^\d+$/ ;
-                    return $txt ;
-                  } ,
-
-  on_F         => sub {
-                    my ( $this , $txt ) = @_ ;
-                    return "<b><i>$txt</i></b>" ;
-                  } ,
-
   on_I         => sub {
                     my ( $this , $txt ) = @_ ;
                     return "<i>$txt</i>" ;
                   } ,
 
-  on_L         => sub {
-                    my ( $this , $L , $text, $page , $section, $type ) = @_ ;
-                    if   ( $type eq 'pod' ) {
-		      $section = defined $section ? "#$section" : ''; 
-		      $page = '' unless defined $page; 
-                      return "<i><a href='http://search.cpan.org/perldoc?$page$section'>$text</a></i>" ;
-                    }
-                    elsif( $type eq 'man' ) { return "<i>$text</i>" ;}
-                    elsif( $type eq 'url' ) { return "<a href='$page' target='_blank'>$text</a>" ;}
-                  } ,
-
-  on_S         => sub {
+  on_C         => sub {
                     my ( $this , $txt ) = @_ ;
-                    $txt =~ s/\n/ /gs ;
-                    return $txt ;
+                    return "<pre>$txt</pre>" ;
                   } ,
 
-  on_X         => sub { return '' ; } ,
-
-  on_Z         => sub { return '' ; } ,
-
-  on_back      => sub {
-		    my $this = shift ;
-		    return "</ul>\n" ;
-  		  } ,
-
-  on_begin     => sub {
-		    my $this = shift ;
-		    my ( $txt , $a_name ) = @_ ;
-		    $this->{IN_BEGIN} = 1;
-		    return '';
-  		  } ,
-
-  on_error     => sub {
+  on_verbatin  => sub {
                     my ( $this , $txt ) = @_ ;
-                    return "<!-- POD_ERROR: $txt -->" ;
+                    return "<pre>$txt</pre>\n" ;
                   } ,
 
-  on_end       => sub { 
-		    my $this = shift ;
-		    my ( $txt , $a_name ) = @_ ;
-		    delete $this->{IN_BEGIN};
-		    return '';
+  on_textblock => sub {
+                    my ( $this , $txt ) = @_ ;
+                    return "<p>$txt</p>\n" ;
                   } ,
 
-  on_for       => sub { return '' ;} ,
-
-  on_head1     => sub {
-                    my ( $this , $txt , $a_name ) = @_ ;
-                    return "<a name='$a_name'></a><h1>$txt</h1>\n\n" ;
-                  } ,
-
-  on_head2     => sub {
-                    my ( $this , $txt , $a_name ) = @_ ;
-                    return "<a name='$a_name'></a><h2>$txt</h2>\n\n" ;
-                  } ,
-
-  on_head3     => sub {
-                    my ( $this , $txt , $a_name ) = @_ ;
-                    return "<a name='$a_name'></a><h3>$txt</h3>\n\n" ;
-                  } ,
-
-  on_head4     => sub {
-                    my ( $this , $txt , $a_name ) = @_ ;
-                    return "<a name='$a_name'></a><h4>$txt</h4>\n\n" ;
-                  } ,
-
-  on_include   => sub {
-                    my ( $this , $file ) = @_ ;
-                    return "./$file" ;
+  on_over      => sub {
+                    my ( $this , $level ) = @_ ;
+                    return "<ul>\n" ;
                   } ,
 
   on_item      => sub {
@@ -885,52 +624,44 @@ Complete usage:
                     return "<li>$txt</li>\n" ;
                   } ,
 
+  on_back      => sub {
+                    my $this = shift ;
+                    return "</ul>\n" ;
+                  } ,
+                  
+  on_include   => sub {
+                    my ( $this , $file ) = @_ ;
+                    return "./$file" ;
+                  }
+  
+  on_error     => sub {
+                    my ( $this , $txt ) = @_ ;
+                    return "<!-- POD_ERROR: $txt -->" ;
+                  } ,
+
   on_index_node_start => sub {
-		    my ( $this , $txt , $a_name , $has_childs ) = @_ ;
-		    my $ret = "<li><a href='#$a_name'>$txt</a>\n" ;
-		    $ret .= "\n<ul>\n" if $has_childs ;
-		    return $ret ;
-		  } ,
+                           my ( $this , $txt , $a_name , $has_childs ) = @_ ;
+                           my $ret = "<li><a href='#$a_name'>$txt</a>\n" ;
+                           $ret .= "\n<ul>\n" if $has_childs ;
+                           return $ret ;
+                         } ,
 
   on_index_node_end => sub {
-		    my $this = shift ;
-		    my ( $txt , $a_name , $has_childs ) = @_ ;
-		    my $ret = $has_childs ? "</ul>" : '' ;
-		    return $ret ;
-		  } ,
+                         my $this = shift ;
+                         my ( $txt , $a_name , $has_childs ) = @_ ;
+                         my $ret = "</ul>" if $has_childs ;
+                         return $ret ;
+                       } ,
 
-  on_over      => sub {
-                    my ( $this , $level ) = @_ ;
-                    return "<ul>\n" ;
-                  } ,
-
-  on_textblock => sub {
-                    my ( $this , $txt ) = @_ ;
-		    return if exists $this->{IN_BEGIN};
-                    return "<p>$txt</p>\n" ;
-                  } ,
-
-  on_uri       => sub {
-                    my ( $this , $uri ) = @_ ;
-                    return "<a href='$uri' target='_blank'>$uri</a>" ;
-                  } ,
-
-  on_verbatim  => sub {
-                    my ( $this , $txt ) = @_ ;
-		    $txt =~ s{(^[\r\n])*(^[\r\n])\z}{}mg;
-		    return '' unless length $txt;
-                    return "<pre>$txt</pre>\n" ;
-                  } ,
   ) ;
-
+  
   ## Convert to HTML:
 
-  my $html = $podhtml->pod2html('test.pod' ,
-  				'test.html' ,
-			        title => 'POD::Test' ,
-			        body  => { bgcolor => '#CCCCCC' } ,
-			        css   => 'test.css' ,
-			       ) ;
+  my $html = $podhtml->pod2html('test.pod' , 'test.html' ,
+  title => 'POD::Test' ,
+  body => { bgcolor => '#CCCCCC' } ,
+  css => 'test.css' ,
+  ) ;
 
 =head1 METHODS
 
@@ -938,31 +669,39 @@ Complete usage:
 
 By default the object has it own subs to handler the events.
 
-But if you want to personalize/overwrite them you can set the keys in the initialization:
+But if you want to personalize/overwrite them you can set this keys in the initialization:
 
-I<(For examples of how to implement the event subs see L<USAGE> above).>
+I<(For examples of how to implement the event subs see L<"USAGE"> above).>
 
 =over 10
 
-=item on_B ( $txt )
+=item on_head1 ( $txt , $a_name )
 
-When I<B>I<<>I<...>I<>> is found. I<(bold text).>
+When I<=head1> is found.
 
-=item on_C ( $txt )
+=over 10
 
-When I<C>I<<>I<...>I<>> is found. I<(code text).>
+=item $txt
 
-=item on_E ( $txt )
+The text of the command.
 
-When I<E>I<<>I<...>I<>> is found. I<(a character escape).>
+=item $a_name
 
-=item on_I ( $txt )
+The text of the command filtered to be used as I<<a name="$a_name">>.
 
-When I<I>I<<>I<...>I<>> is found. I<(italic text).>
+=back
+
+=item on_head2 ( $txt , $a_name )
+
+When I<=head2> is found. See I<on_head1>.
+
+=item on_head3 ( $txt , $a_name )
+
+When I<=head2> is found. See I<on_head1>.
 
 =item on_L ( $L , $text, $page , $section, $type )
 
-When I<L>I<<>I<...>I<>> is found. I<(Link).>
+When I<L>I<<>I<...>I<>> is found.
 
 =over 10
 
@@ -988,86 +727,47 @@ The type of the link: pod, man, url.
 
 =back
 
-=item on_F ( $txt )
 
-When I<F>I<<>I<...>I<>> is found. I<(used for filenames).>
+=item on_B ( $txt )
 
-=item on_S ( $txt )
+When I<B>I<<>I<...>I<>> is found.
 
-When I<S>I<<>I<...>I<>> is found. I<(text contains non-breaking spaces).>
+=item on_I ( $txt )
 
-=item on_X ( $txt )
+When I<I>I<<>I<...>I<>> is found.
 
-When I<X>I<<>I<...>I<>> is found. I<(a null (zero-effect) formatting code).>
+=item on_C ( $txt )
 
-=item on_Z ( $txt )
+When I<C>I<<>I<...>I<>> is found.
 
-When I<Z>I<<>I<...>I<>> is found. I<(a null (zero-effect) formatting code).>
+=item on_verbatin ( $txt )
 
-=item on_back 
+When VERBATIN data is found.
 
-When I<=back> is found.
+=item on_textblock ( $txt )
 
-=item on_begin
+When normal text blocks are found.
 
-When I<=begin> is found.
+=item on_over ( $level )
 
-By default everything from '=begin' to '=end' is ignored.
-
-=item on_error ( $txt )
-
-Called on POD syntax error occurrence.
-
-=item on_head1 ( $txt , $a_name )
-
-When I<=head1> is found.
-
-=over 10
-
-=item $txt
-
-The text of the command.
-
-=item $a_name
-
-The text of the command filtered to be used as I<<a name="$a_name"></a>>.
-
-=back
-
-=item on_head2 ( $txt , $a_name )
-
-When I<=head2> is found. See I<on_head1>.
-
-=item on_head3 ( $txt , $a_name )
-
-When I<=head3> is found. See I<on_head1>.
-
-=item on_head4 ( $txt , $a_name )
-
-When I<=head4> is found. See I<on_head1>.
-
-=item on_for
-
-When I<=for> is found.
-
-I<By default '=for' is ignored!>
+When I<=over X> is found.
 
 =item on_item ( $txt )
 
 When I<=item foo> is found.
 
-=item on_end
+=item on_back 
 
-When I<=end> is found.
-
-See '=begin' above.
+When I<=back> is found.
 
 =item on_include ( $file )
 
-When I<=include> is found.
-
 Should be used only to handle the localtion of the $file.
 
+=item on_error ( $txt )
+
+Called on POD syntax error occurrence.
+
 =item on_index_node_start ( $txt , $a_name , $has_childs )
 
 Called to build the INDEX. This is called when a node is start.
@@ -1080,25 +780,6 @@ Called to build the INDEX. This is called when a node ends.
 
 I<$has_childs> can be used to know if the node has childs (sub-nodes).
 
-=item on_over ( $level )
-
-When I<=over X> is found.
-
-=item on_textblock ( $txt )
-
-When normal text blocks are found.
-
-=item on_uri ( $uri )
-
-When an URI (URL, E-MAIL, etc...) is found.
-
-=item on_verbatim ( $txt )
-
-When VERBATIM data is found, trailing empty lines are deleted.
-
-Note: This interface was previously called "on_verbatin".
-That interface has been retained for backwards compatibility.
-
 =back
 
 =head2 pod2html ( POD_FILE|POD_DATA|FILEHANDLER , HTML_FILE , %OPTIONS )
@@ -1115,7 +796,7 @@ The POD file (file path) , data (SCALAR) or FILEHANDLER (GLOB opened).
 
 The output HTML file path.
 
-I<** Note that the method also returns the HTML data generated, so you also can use it wihtout generate files.>
+I<** Note that the method also returns the HTML data generated, soo you also can use it wihtout generate files.>
 
 =item %OPTIONS I<(optional)>
 
@@ -1134,11 +815,11 @@ The body values.
 Examples:
 
   body => q`alink="#FF0000" bgcolor="#FFFFFF" link="#000000" text="#000000" vlink="#000066"` ,
-
+  
   ## Or:
-
+  
   body => { bgcolor => "#CCCCCC" , link => "#0000FF" } , ## This will overwrite only this 2 values,
-
+                                                         ## the other default values are kept.
 
 ** I<Default: alink="#FF0000" bgcolor="#FFFFFF" link="#000000" text="#000000" vlink="#000066">
 
@@ -1149,9 +830,9 @@ Can be a css file path (HREF) or the css data.
 Examples:
 
   css => 'test.css' ,
-
+  
   ## Or:
-
+  
   css => q`
     BODY {
       background: white;
@@ -1168,10 +849,6 @@ Examples:
     }
   ` ,
 
-=item top
-
-Set a TOP data. The HTML paste with I<top> will be added just before the I<index>.
-
 =item index
 
 Set the index data. If not set will generate automatically, calling the events subs I<on_index_node_start> and I<on_index_node_end>
@@ -1188,26 +865,6 @@ If I<TRUE> tell to not use css.
 
 If I<TRUE> tell to only generate the HTML content (between <body>...</body>).
 
-=item index_item
-
-If I<TRUE> items will be added in the index.
-
-=item basic_entities
-
-If TRUE encode only basic entities:
-
-  & < >
-
-=item common_entities
-
-If TRUE encode only common entities:
-
-  & < >                           
-
-=item no_generator
-
-If TRUE the meta GENERATOR tag won't be added.
-
 =back
 
 =back
@@ -1220,48 +877,8 @@ Return the version of a Perl Module file.
 
 Return the package name of a Perl Module file.
 
-=head2 pm_name
-
-Returns I<=head1 NAME> description.
-
-=head2 pm_package_version_name
-
-Returns all the 3 values at the same time.
-
-=head2 default_css
-
-Returns the default CSS.
-
-=head1 EXTENDING POD
-
-You can extend POD defining non-standard events.
-
-For example, to enable the command I<"=hr">:
-
-  my $podhtml = Pod::HtmlEasy->new(
-  on_hr => sub {
-            my ( $this , $txt ) = @_ ;
-            return "<hr>" ;
-           }
-  ) ;
-
-To define a new formatting code, do the same thing, but the code must be a single letter.
-
-So, to enable I<"G>I<<...>I<>>I<">:
-
-  my $podhtml = Pod::HtmlEasy->new(
-  on_G => sub {
-            my ( $this , $txt ) = @_ ;
-            return "<img src='$txt' border=0>" ;
-          }
-  ) ;
-
 =head1 DEFAULT CSS
 
-This is the default CSS added to the HTML.
-
-I<** If you will set your own CSS use this as base.>
-
   BODY {
     background: white;
     color: black;
@@ -1359,18 +976,11 @@ I<** If you will set your own CSS use this as base.>
     list-style-type: none;
   }
 
-=head1 DIAGNOSTICS
-
-HtmlEasy does not produce any messages I<other> than those that result from
-the C<use warnings> specified for each module. The maintainer would appreciate
-hearing about any such.
-
-HtmlEasy uses Pod::Parser, which may produce error messages concerning malformed
-HTML.
-
 =head1 SEE ALSO
 
-L<Pod::Parser> L<perlpod>.
+L<Pod::Parser>, L<Pod::Master>, L<Pod::Master::Html>.
+
+L<perlpod>.
 
 =head1 AUTHOR
 
@@ -1378,13 +988,6 @@ Graciliano M. P. <gm@virtuasites.com.br>
 
 I will appreciate any type of feedback (include your opinions and/or suggestions). ;-P
 
-Thanks to Ivan Tubert-Brohman <itub@cpan.org> that suggested to add the basic_entities
-and common_entities options and for tests.
-
-=head1 MAINTENANCE
-
-Updates for version 0.8_01 by Geoffrey Leach <gleach@cpan.org>
-
 =head1 COPYRIGHT
 
 This program is free software; you can redistribute it and/or
